# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing.framework
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .tab_bar_button import TabBarButton as TabBarButton_6ab41098

class XTabBar(ABC):
    """
    UI control for the selection of views in a pane.
    
    Every tab of a tab bar has, besides its localized title and help text, the URL of a view. A possible alternative would be to use a command URL instead of the view URL.
    
    In the current Impress implementation a tab bar is only used for the center pane to switch between views in the center pane. Tab bars can make sense for other panes as well, i.e. for showing either the slide sorter or the outline view in the left pane.
    
    Tab bar buttons are identified by their resource id. Note that because the resource anchors are all the same (the tab bar), it is the resource URL that really identifies a button. There can not be two buttons with the same resource id.
    
    A better place for this interface (in an extended version) would be com.sun.star.awt

    See Also:
        `API XTabBar <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XTabBar.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.XTabBar'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.framework.XTabBar'

    @abstractmethod
    def addTabBarButtonAfter(self, aButton: TabBarButton_6ab41098, aAnchor: TabBarButton_6ab41098) -> None:
        """
        Add a tab bar button to the right of another one.
        """
        ...
    @abstractmethod
    def appendTabBarButton(self, aButton: TabBarButton_6ab41098) -> None:
        """
        Add a tab bar button at the right most position.
        """
        ...
    @abstractmethod
    def getTabBarButtons(self) -> typing.Tuple[TabBarButton_6ab41098, ...]:
        """
        Return a sequence of all the tab bar buttons.
        
        Their order reflects the visible order in the tab bar.
        
        This method can be used when addTabBarButtonAfter() does not provide enough control as to where to insert a new button.
        """
        ...
    @abstractmethod
    def hasTabBarButton(self, aButton: TabBarButton_6ab41098) -> bool:
        """
        Test whether the specified button exists in the tab bar.
        """
        ...
    @abstractmethod
    def removeTabBarButton(self, aButton: TabBarButton_6ab41098) -> None:
        """
        Remove a tab bar button.
        """
        ...

__all__ = ['XTabBar']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet


class DataPilotFieldReferenceType(object):
    """
    Const Class

    These constants select different types of References to calculate the data fields.

    See Also:
        `API DataPilotFieldReferenceType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldReferenceType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.DataPilotFieldReferenceType'
    __ooo_type_name__: str = 'const'

    NONE = 0
    """
    This type means, that the results in the data fields are displayed like they are.
    """
    ITEM_DIFFERENCE = 1
    """
    From each result, its reference value (see below) is subtracted, and the difference is shown.
    
    Totals outside of the base field are shown as empty results.
    
    Named Item
    
    If a base item name is specified, the reference value for a combination of field items is the result where the item in the base field is replaced by the specified base item.
    
    If the reference value isn't shown in the DataPilot table because of hidden details for a parent field, the difference isn't calculated and an error value is shown.
    
    If the result for an item combination is empty, the value 0 is used for the difference, even if the summary function is undefined without values, like average or variance. The difference is shown in the result table even if the original result was empty.
    
    The difference for item combinations containing the base item is shown as empty result.
    
    Previous or Next
    
    If \"previous\" or \"next\" is specified as the base item, the reference value is the result for the next visible member of the base field, in the base field's sort order. If details for one item in the base field are hidden, that item is skipped. The difference for the item with hidden details isn't calculated, not even for the item's summary, to have a consistent order of previous and next items.
    
    Empty results are handled as for named items (see above).
    
    The difference for the first (for com.sun.star.sheet.DataPilotFieldReferenceItemType.PREVIOUS) or last (for com.sun.star.sheet.DataPilotFieldReferenceItemType.NEXT ) item of the base field is shown as empty result.
    """
    ITEM_PERCENTAGE = 2
    """
    Each result is divided by its reference value.
    
    The reference value is determined in the same way as for com.sun.star.sheet.DataPilotFieldReferenceType.ITEM_DIFFERENCE. Totals outside of the base field are shown as empty results.
    
    Division by zero results in an error. Otherwise, empty results are shown as 0. Results for the base item, first (for com.sun.star.sheet.DataPilotFieldReferenceItemType.PREVIOUS) or last (for com.sun.star.sheet.DataPilotFieldReferenceItemType.NEXT) item of the base field are shown as 1 if not empty.
    """
    ITEM_PERCENTAGE_DIFFERENCE = 3
    """
    From each result, its reference value is subtracted, and the difference divided by the reference value.
    
    The reference value is determined in the same way as for com.sun.star.sheet.DataPilotFieldReferenceType.ITEM_DIFFERENCE. Totals outside of the base field are shown as empty results.
    
    Division by zero results in an error. Otherwise, the rules for com.sun.star.sheet.DataPilotFieldReferenceType.ITEM_DIFFERENCE apply.
    """
    RUNNING_TOTAL = 4
    """
    Each result is added to the sum of the results for preceding items in the base field, in the base field's sort order, and the total sum is shown.
    
    If details for one item in the base field are hidden, that item isn't included in calculating the sum, and results for that item are shown as error, to ensure consistency between details and subtotals for the following items.
    
    Results are always summed, even if a different summary function was used to get each result.
    
    Totals outside of the base field are shown as empty results.
    """
    ROW_PERCENTAGE = 5
    """
    Each result is divided by the total result for its row in the DataPilot table.
    
    If there are several data fields, the total for the result's data field is used.
    
    If there are subtotals with manually selected summary functions, still the total with the data field's summary function is used.
    
    Division by zero results in an error.
    
    Otherwise, empty results remain empty.
    """
    COLUMN_PERCENTAGE = 6
    """
    Same as com.sun.star.sheet.DataPilotFieldReferenceType.ROW_PERCENTAGE, but the total for the result's column is used.
    """
    TOTAL_PERCENTAGE = 7
    """
    Same as com.sun.star.sheet.DataPilotFieldReferenceType.ROW_PERCENTAGE, but the grand total for the result's data field is used.
    """
    INDEX = 8
    """
    The row and column totals and the grand total, following the same rules as above, are used to calculate the following expression.
    
    ( original result * grand total ) / ( row total * column total )
    
    Division by zero results in an error. Otherwise, empty results remain empty.
    """

__all__ = ['DataPilotFieldReferenceType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_conditional_format import XConditionalFormat as XConditionalFormat_be90e56
if typing.TYPE_CHECKING:
    from .x_sheet_cell_ranges import XSheetCellRanges as XSheetCellRanges_edef0d52

class ConditionalFormat(XPropertySet_bc180bfa, XConditionalFormat_be90e56):
    """
    Service Class

    represents a conditional format

    See Also:
        `API ConditionalFormat <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1ConditionalFormat.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.ConditionalFormat'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ID(self) -> int:
        """
        """
        ...

    @abstractproperty
    def Range(self) -> XSheetCellRanges_edef0d52:
        """
        represents the range for the conditional format All ranges have to be in the same sheet.
        """
        ...


__all__ = ['ConditionalFormat']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.dom
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_document import XDocument as XDocument_aebc0b5e
    from .x_document_type import XDocumentType as XDocumentType_e0340d00

class XDOMImplementation(XInterface_8f010a43):
    """

    See Also:
        `API XDOMImplementation <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XDOMImplementation.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.dom'
    __ooo_full_ns__: str = 'com.sun.star.xml.dom.XDOMImplementation'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.dom.XDOMImplementation'

    @abstractmethod
    def createDocument(self, namespaceURI: str, qualifiedName: str, doctype: XDocumentType_e0340d00) -> XDocument_aebc0b5e:
        """
        Creates a DOM Document object of the specified type with its document element.
        
        Throws: DOMException - INVALID_CHARACTER_ERR: Raised if the specified qualified name contains an illegal character. NAMESPACE_ERR: Raised if the qualifiedName is malformed, if the qualifiedName has a prefix and the namespaceURI is null, or if the qualifiedName has a prefix that is \"xml\" and the namespaceURI is different from \" http://www.w3.org/XML/1998/namespace\" , or if the DOM implementation does not support the \"XML\" feature but a non-null namespace URI was provided, since namespaces were defined by XML. WRONG_DOCUMENT_ERR: Raised if doctype has already been used with a different document or was created from a different implementation. NOT_SUPPORTED_ERR: May be raised by DOM implementations which do not support the \"XML\" feature, if they choose not to support this method. Other features introduced in the future, by the DOM WG or in extensions defined by other groups, may also demand support for this method; please consult the definition of the feature to see if it requires this method.

        Raises:
            DOMException: ``DOMException``
        """
        ...
    @abstractmethod
    def createDocumentType(self, qualifiedName: str, publicId: str, systemId: str) -> XDocumentType_e0340d00:
        """
        Creates an empty DocumentType node.
        
        Throws: DOMException - INVALID_CHARACTER_ERR: Raised if the specified qualified name contains an illegal character. NAMESPACE_ERR: Raised if the qualifiedName is malformed. NOT_SUPPORTED_ERR: May be raised by DOM implementations which do not support the \"XML\" feature, if they choose not to support this method. Other features introduced in the future, by the DOM WG or in extensions defined by other groups, may also demand support for this method; please consult the definition of the feature to see if it requires this method.

        Raises:
            DOMException: ``DOMException``
        """
        ...
    @abstractmethod
    def hasFeature(self, feature: str, ver: str) -> bool:
        """
        Test if the DOM implementation implements a specific feature.
        """
        ...

__all__ = ['XDOMImplementation']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .formula_token import FormulaToken as FormulaToken_bd1c0bf8

class XMultiFormulaTokens(ABC):
    """
    gives access to multiple sets of formula tokens.
    
    A service implementing this interface can internally set an arbitrary number of formula token sequences. The number of allowed formula token sequences must be returned by the com.sun.star.sheet.XMultiFormulaTokens.getCount() method. When the client code tries to access formula tokens at index that is outside the allowed index range, the implementation shall return an com.sun.star.lang.IndexOutOfBoundsException.

    See Also:
        `API XMultiFormulaTokens <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XMultiFormulaTokens.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XMultiFormulaTokens'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XMultiFormulaTokens'

    @abstractmethod
    def getCount(self) -> int:
        """
        returns the number of formulas allowed in this formula token set.
        """
        ...
    @abstractmethod
    def getTokens(self, nIndex: int) -> typing.Tuple[FormulaToken_bd1c0bf8, ...]:
        """
        returns the formula at specified index as sequence of tokens.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def setTokens(self, nIndex: int, aTokens: typing.Tuple[FormulaToken_bd1c0bf8, ...]) -> None:
        """
        sets the formula at specified index as sequence of tokens.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...

__all__ = ['XMultiFormulaTokens']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.lang.array_index_out_of_bounds_exception import ArrayIndexOutOfBoundsException as ArrayIndexOutOfBoundsException
from ...lo.lang.class_not_found_exception import ClassNotFoundException as ClassNotFoundException
from ...lo.lang.disposed_exception import DisposedException as DisposedException
from ...lo.lang.event_object import EventObject as EventObject
from ...lo.lang.illegal_access_exception import IllegalAccessException as IllegalAccessException
from ...lo.lang.illegal_argument_exception import IllegalArgumentException as IllegalArgumentException
from ...lo.lang.index_out_of_bounds_exception import IndexOutOfBoundsException as IndexOutOfBoundsException
from ...lo.lang.invalid_listener_exception import InvalidListenerException as InvalidListenerException
from ...lo.lang.listener_exist_exception import ListenerExistException as ListenerExistException
from ...lo.lang.locale import Locale as Locale
from ...lo.lang.multi_service_factory import MultiServiceFactory as MultiServiceFactory
from ...lo.lang.no_such_field_exception import NoSuchFieldException as NoSuchFieldException
from ...lo.lang.no_such_method_exception import NoSuchMethodException as NoSuchMethodException
from ...lo.lang.no_support_exception import NoSupportException as NoSupportException
from ...lo.lang.not_initialized_exception import NotInitializedException as NotInitializedException
from ...lo.lang.null_pointer_exception import NullPointerException as NullPointerException
from ...lo.lang.registry_service_manager import RegistryServiceManager as RegistryServiceManager
from ...lo.lang.service_manager import ServiceManager as ServiceManager
from ...lo.lang.service_not_registered_exception import ServiceNotRegisteredException as ServiceNotRegisteredException
from ...lo.lang.system_dependent import SystemDependent as SystemDependent
from ...lo.lang.wrapped_target_exception import WrappedTargetException as WrappedTargetException
from ...lo.lang.wrapped_target_runtime_exception import WrappedTargetRuntimeException as WrappedTargetRuntimeException
from ...lo.lang.x_component import XComponent as XComponent
from ...lo.lang.x_connection_point import XConnectionPoint as XConnectionPoint
from ...lo.lang.x_connection_point_container import XConnectionPointContainer as XConnectionPointContainer
from ...lo.lang.x_event_listener import XEventListener as XEventListener
from ...lo.lang.x_initialization import XInitialization as XInitialization
from ...lo.lang.x_localizable import XLocalizable as XLocalizable
from ...lo.lang.x_main import XMain as XMain
from ...lo.lang.x_multi_component_factory import XMultiComponentFactory as XMultiComponentFactory
from ...lo.lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory
from ...lo.lang.x_service_display_name import XServiceDisplayName as XServiceDisplayName
from ...lo.lang.x_service_info import XServiceInfo as XServiceInfo
from ...lo.lang.x_service_name import XServiceName as XServiceName
from ...lo.lang.x_single_component_factory import XSingleComponentFactory as XSingleComponentFactory
from ...lo.lang.x_single_service_factory import XSingleServiceFactory as XSingleServiceFactory
from ...lo.lang.x_type_provider import XTypeProvider as XTypeProvider
from ...lo.lang.x_uno_tunnel import XUnoTunnel as XUnoTunnel



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class SymbolStyle(metaclass=UnoEnumMeta, type_name="com.sun.star.chart2.SymbolStyle", name_space="com.sun.star.chart2"):
        """Dynamically created class that represents ``com.sun.star.chart2.SymbolStyle`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.chart2.SymbolStyle import AUTO as SYMBOL_STYLE_AUTO
        from com.sun.star.chart2.SymbolStyle import GRAPHIC as SYMBOL_STYLE_GRAPHIC
        from com.sun.star.chart2.SymbolStyle import NONE as SYMBOL_STYLE_NONE
        from com.sun.star.chart2.SymbolStyle import POLYGON as SYMBOL_STYLE_POLYGON
        from com.sun.star.chart2.SymbolStyle import STANDARD as SYMBOL_STYLE_STANDARD

        class SymbolStyle(uno.Enum):
            """
            Enum Class


            See Also:
                `API SymbolStyle <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1chart2.html#a8068445d248b830d1708dcb2a2afb2c6>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.chart2.SymbolStyle', value)

            __ooo_ns__: str = 'com.sun.star.chart2'
            __ooo_full_ns__: str = 'com.sun.star.chart2.SymbolStyle'
            __ooo_type_name__: str = 'enum'

            AUTO = SYMBOL_STYLE_AUTO
            """
            The symbol is taken automatically.
            """
            GRAPHIC = SYMBOL_STYLE_GRAPHIC
            """
            uses the graphic given in Symbol.Graphic as symbol.
            """
            NONE = SYMBOL_STYLE_NONE
            """
            Default, no pies are exploded.

            no transparency attribute is evaluated

            The symbol is invisible.
            """
            POLYGON = SYMBOL_STYLE_POLYGON
            """
            uses the symbol given in the com.sun.star.drawing.PolyPolygonBezierCoords given in Symbol.PolygonCoords.
            """
            STANDARD = SYMBOL_STYLE_STANDARD
            """
            uses one of the standard symbols.

            Which standard symbol is given in Symbol.StandardSymbol.
            """
    else:
        # keep document generators happy
        from ...lo.chart2.symbol_style import SymbolStyle as SymbolStyle


__all__ = ['SymbolStyle']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9
    from ..awt.x_window import XWindow as XWindow_713b0924

class XDockingAreaAcceptor(XInterface_8f010a43):
    """
    this interface enables developer to implement different docking area acceptors which are used by the frame based layout manager.
    
    A docking area acceptor is responsible to control the docking area of a container window. As OLE for example supports inplace and outplace editing, there are different parts of code responsible for the container window. This interface enables developer to make support implementations for these scenarios.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XDockingAreaAcceptor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XDockingAreaAcceptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.XDockingAreaAcceptor'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ui.XDockingAreaAcceptor'

    @abstractmethod
    def getContainerWindow(self) -> XWindow_713b0924:
        """
        provide the container window where the layout manager can request border space for docking windows.
        
        Additionally the layout manager uses this window to create its own child windows for docking purposes.
        """
        ...
    @abstractmethod
    def requestDockingAreaSpace(self, RequestedSpace: Rectangle_84b109e9) -> bool:
        """
        method to ask an implementation if the provided space for docking windows is available or not.
        
        The com.sun.star.awt.Rectangle parameter is filled by the caller with pixel data. The members of com.sun.star.awt.Rectangle must be filled as following:
        """
        ...
    @abstractmethod
    def setDockingAreaSpace(self, BorderSpace: Rectangle_84b109e9) -> None:
        """
        method to brief an implementation that we need new border space.
        
        The callee must size its document window so that we have the amount of space we have provided. The com.sun.star.awt.Rectangle parameter is filled by the caller with pixel data. The members of com.sun.star.awt.Rectangle must be filled as following:
        """
        ...

__all__ = ['XDockingAreaAcceptor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.crypto.sax
from __future__ import annotations
import typing
from abc import abstractmethod
from ....uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_decryption_result_listener import XDecryptionResultListener as XDecryptionResultListener_282814e0

class XDecryptionResultBroadcaster(XInterface_8f010a43):
    """
    Interface of Decryption Result Broadcaster.
    
    This interface is used to manipulate decryption result listener.

    See Also:
        `API XDecryptionResultBroadcaster <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1XDecryptionResultBroadcaster.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.crypto.sax'
    __ooo_full_ns__: str = 'com.sun.star.xml.crypto.sax.XDecryptionResultBroadcaster'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.crypto.sax.XDecryptionResultBroadcaster'

    @abstractmethod
    def addDecryptionResultListener(self, listener: XDecryptionResultListener_282814e0) -> None:
        """
        Adds a new decryption result listener.
        
        When the decryption is finished, the result information will be sent to this listener.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def removeDecryptionResultListener(self, listener: XDecryptionResultListener_282814e0) -> None:
        """
        Removes a decryption result listener.
        
        After a listener is removed, no result information will be sent to it.
        """
        ...

__all__ = ['XDecryptionResultBroadcaster']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.report


class Calculation(object):
    """
    Const Class

    Specifies how to calculate a value.

    See Also:
        `API Calculation <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1report_1_1Calculation.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.report'
    __ooo_full_ns__: str = 'com.sun.star.report.Calculation'
    __ooo_type_name__: str = 'const'

    NONE = 0
    """
    returns the average of a field.
    """
    AVERAGE = 1
    """
    returns the average of a field.
    """
    CORRELATION = 2
    """
    returns the correlation of two fields.
    """
    COUNT = 3
    """
    counts the number of values, from the field.
    """
    COVARIANCE = 4
    """
    returns the measure of the linear relation between paired variables.
    """
    DISTINCTCOUNT = 5
    """
    returns the number of none repeating values, from the field.
    """
    MAXIMUM = 6
    """
    returns the largest value from the field.
    """
    MEDIAN = 7
    """
    returns the middle value in a sequence of numeric values.
    """
    MINIMUM = 8
    """
    returns the smallest value from the field.
    """
    MODE = 9
    """
    returns the most frequently returning value from the field.
    """
    NTHLARGEST = 10
    """
    returns the Nth largest value from the field.
    """
    NTHMOSTFREQUENT = 11
    """
    returns the Nth most commonly occurring value from the field.
    """
    NTHSMALLEST = 12
    """
    returns the Nth smallest value from the field.
    """
    PERCENTAGE = 13
    """
    returns as a percentage of the grand total summary.
    """
    PERCENTILE = 14
    """
    returns the value for a specified percentile in a Number or Currency field.
    """
    POPSTANDARDDEVIATION = 15
    """
    returns how much each value in the field deviate from the mean or average value for that field.
    """
    POPVARIANCE = 16
    """
    returns the square of the standard deviation.
    """
    SAMPLESTANDARDDEVIATION = 17
    """
    returns the sample standard deviation for the field.
    """
    SAMPLEVARIANCE = 18
    """
    returns the sample variance for the field.
    """
    SUM = 19
    """
    returns the total of all the values for the field.
    """
    WEIGHTEDAVG = 20
    """
    returns the weighted average for the field.
    """

__all__ = ['Calculation']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.ucb.SearchRecursion import SearchRecursionProto

class SearchRecursion(Enum):
    """
    Enum Class


    See Also:
        `API SearchRecursion <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb.html#a8f357eda7c29e9601428bdc8834c7bd8>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.SearchRecursion'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.ucb.SearchRecursion'

    DEEP = cast("SearchRecursionProto", 'DEEP')
    """
    Searches through the complete hierarchy of all sub-objects.
    """
    NONE = cast("SearchRecursionProto", 'NONE')
    """
    Does not search through any sub-objects.
    """
    ONE_LEVEL = cast("SearchRecursionProto", 'ONE_LEVEL')
    """
    Only searches through sub-objects of the first hierarchy level.
    """

__all__ = ['SearchRecursion']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_text_range import XTextRange as XTextRange_9a910ab7
if typing.TYPE_CHECKING:
    from .x_text_cursor import XTextCursor as XTextCursor_a60c0b48

class XSimpleText(XTextRange_9a910ab7):
    """
    is the main interface for a distinct text unit, i.e.
    
    the main text of a document, the text for headers and footers or for single cells of a table.

    See Also:
        `API XSimpleText <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XSimpleText.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.XSimpleText'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.text.XSimpleText'

    @abstractmethod
    def createTextCursor(self) -> XTextCursor_a60c0b48:
        """
        """
        ...
    @abstractmethod
    def createTextCursorByRange(self, aTextPosition: XTextRange_9a910ab7) -> XTextCursor_a60c0b48:
        """
        The initial position is set to aTextPosition.
        """
        ...
    @abstractmethod
    def insertControlCharacter(self, xRange: XTextRange_9a910ab7, nControlCharacter: int, bAbsorb: bool) -> None:
        """
        inserts a control character (like a paragraph break or a hard space) into the text.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def insertString(self, xRange: XTextRange_9a910ab7, aString: str, bAbsorb: bool) -> None:
        """
        inserts a string of characters into the text.
        
        The string may contain the following white spaces:
        
        If the parameter bAbsorb() was TRUE the text range will contain the new inserted string, otherwise the range (and it's text) will remain unchanged.
        """
        ...

__all__ = ['XSimpleText']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.gallery
from __future__ import annotations
import typing
from abc import abstractmethod
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
if typing.TYPE_CHECKING:
    from .x_gallery_theme import XGalleryTheme as XGalleryTheme_e28e0d13

class XGalleryThemeProvider(XNameAccess_e2ab0cf6):
    """
    provides access to the Gallery themes.
    
    It also allows inserting and removing of Gallery themes by name.
    
    This interface extends the interface com.sun.star.container.XNameAccess which provides access to existing Gallery themes collection.

    See Also:
        `API XGalleryThemeProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1gallery_1_1XGalleryThemeProvider.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.gallery'
    __ooo_full_ns__: str = 'com.sun.star.gallery.XGalleryThemeProvider'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.gallery.XGalleryThemeProvider'

    @abstractmethod
    def insertNewByName(self, ThemeName: str) -> XGalleryTheme_e28e0d13:
        """
        creates a new Gallery theme and adds it to the collection.

        Raises:
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
        ...
    @abstractmethod
    def removeByName(self, ThemeName: str) -> None:
        """
        deletes a Gallery theme from the collection.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...

__all__ = ['XGalleryThemeProvider']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class RelativeSize(object):
    """
    Struct Class

    Gives a position relative to some size defined by other means.
    
    Values from 0 to 1 cover the entire reference rectangle. Values may also be greater than one, meaning a bigger size than the reference size. Negative values are not allowed.

    See Also:
        `API RelativeSize <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart2_1_1RelativeSize.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.RelativeSize'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.chart2.RelativeSize'
    """Literal Constant ``com.sun.star.chart2.RelativeSize``"""

    def __init__(self, Primary: typing.Optional[float] = 0.0, Secondary: typing.Optional[float] = 0.0) -> None:
        """
        Constructor

        Arguments:
            Primary (float, optional): Primary value.
            Secondary (float, optional): Secondary value.
        """
        super().__init__()

        if isinstance(Primary, RelativeSize):
            oth: RelativeSize = Primary
            self.Primary = oth.Primary
            self.Secondary = oth.Secondary
            return

        kargs = {
            "Primary": Primary,
            "Secondary": Secondary,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._primary = kwargs["Primary"]
        self._secondary = kwargs["Secondary"]


    @property
    def Primary(self) -> float:
        """
        The extension in the primary direction.
        
        The direction is defined by the object using this point.
        
        Typically, the direction is determined by an Orientation. Another typical use would be the direction of a given orientation-angle.
        
        The values are relative to the page or an object. Values between 0 and 1 span the complete bounding rectangle of the page/object.
        
        For a western Orientation this is the width.
        """
        return self._primary

    @Primary.setter
    def Primary(self, value: float) -> None:
        self._primary = value

    @property
    def Secondary(self) -> float:
        """
        The extension in the secondary direction.
        
        The direction is defined by the object using this point.
        
        Typically, the direction is determined by an Orientation. Another typical use would be the direction perpendicular to a given orientation-angle.
        
        The values are relative to the page or an object. Values between 0 and 1 span the complete bounding rectangle of the page/object.
        
        For a western Orientation this is the height.
        """
        return self._secondary

    @Secondary.setter
    def Secondary(self, value: float) -> None:
        self._secondary = value


__all__ = ['RelativeSize']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from ..sdbc.x_result_set import XResultSet as XResultSet_98e30aa7
    from .x_dynamic_result_set_listener import XDynamicResultSetListener as XDynamicResultSetListener_56e41050

class XDynamicResultSet(XComponent_98dc0ab5):
    """
    Provides read access to a ContentResultSet.
    
    You can either get a simple static ContentResultSet or you can listen to change-notifications and then swap from the old to a new ContentResultSet.
    
    The following describes the dynamic use:
    
    XDynamicResultSet provides the possibility to get notifications about changes on a ContentResultSet and have an listener-controlled update from one version to the next version. Two ContentResultSet implementations were given to the listener in the first notification as interface com.sun.star.sdbc.XResultSet.
    
    To get notifications the listener has to be of type XDynamicResultSetListener.
    
    After registration you will get notifications for events of type ListEvent.
    
    The calling of XDynamicResultSetListener.notify() has to happen in an own thread, because it could take a longer time and any actions ??? until the listener returns the call. So don't block the notify-causing action.
    
    While one notify-call is going on:
    
    After the listener has returned the notify-call:

    See Also:
        `API XDynamicResultSet <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XDynamicResultSet.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.XDynamicResultSet'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ucb.XDynamicResultSet'

    @abstractmethod
    def connectToCache(self, Cache: XDynamicResultSet) -> None:
        """
        Connects this to a CachedDynamicResultSet for optimized remote data transport.
        
        This method creates a CachedDynamicResultSetStub and sets it as Source to the given cache.
        
        After this method has returned you can and have to use the given result set cache for further access.

        Raises:
            : ````
            : ````
            com.sun.star.ucb.ServiceNotFoundException: ``ServiceNotFoundException``
        """
        ...
    @abstractmethod
    def getCapabilities(self) -> int:
        """
        Using this method you can get information, whether the offered ContentResultSets are sorted or filtered etc correctly as demanded during the creation of the XDynamicResultSet.
        """
        ...
    @abstractmethod
    def getStaticResultSet(self) -> XResultSet_98e30aa7:
        """
        Call this, if you don't care about any changes.

        Raises:
            com.sun.star.ucb.ListenerAlreadySetException: ``ListenerAlreadySetException``
        """
        ...
    @abstractmethod
    def setListener(self, Listener: XDynamicResultSetListener_56e41050) -> None:
        """
        Call this, if you want to get notifications about changes.
        
        The implementor has to call com.sun.star.lang.XComponent.addEventListener() in this method, so that we can call com.sun.star.lang.XEventListener.disposing() at the listener

        Raises:
            com.sun.star.ucb.ListenerAlreadySetException: ``ListenerAlreadySetException``
        """
        ...

__all__ = ['XDynamicResultSet']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.io
from __future__ import annotations
from .x_pipe import XPipe as XPipe_567d07c6

class Pipe(XPipe_567d07c6):
    """
    Service Class

    the implementation of an output stream and an input stream.
    
    All data written through the outputstream is buffered until it is read again from the input stream. Often two different threads access input and outputstream.
    
    With the pipe-service, an outputstream can be converted into an input stream at the cost of an additional buffer.

    See Also:
        `API Pipe <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1io_1_1Pipe.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.Pipe'
    __ooo_type_name__: str = 'service'


__all__ = ['Pipe']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.document
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..uno.exception import Exception as Exception_85530a09
from ..uno.x_interface import XInterface as XInterface_8f010a43

class AmbigousFilterRequest(Exception_85530a09):
    """
    Exception Class

    should be used for interaction to handle states of ambiguous filter detection
    
    This exception indicates, that generic filter detection can't decide which of two filters is the right one. In this case an interaction will be made. Given URL can be used to decide between given two filters. Decision can be made e.g. by a dialog, on which the user must select one of these filters. A possible continuation of type XInteractionFilterSelect transport this decision back to source of started interaction.

    See Also:
        `API AmbigousFilterRequest <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1document_1_1AmbigousFilterRequest.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.AmbigousFilterRequest'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.document.AmbigousFilterRequest'
    __pyunostruct__: str = 'com.sun.star.document.AmbigousFilterRequest'

    typeName: str = 'com.sun.star.document.AmbigousFilterRequest'
    """Literal Constant ``com.sun.star.document.AmbigousFilterRequest``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, URL: typing.Optional[str] = '', SelectedFilter: typing.Optional[str] = '', DetectedFilter: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            URL (str, optional): URL value.
            SelectedFilter (str, optional): SelectedFilter value.
            DetectedFilter (str, optional): DetectedFilter value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "URL": URL,
            "SelectedFilter": SelectedFilter,
            "DetectedFilter": DetectedFilter,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._url = kwargs["URL"]
        self._selected_filter = kwargs["SelectedFilter"]
        self._detected_filter = kwargs["DetectedFilter"]
        inst_keys = ('URL', 'SelectedFilter', 'DetectedFilter')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def URL(self) -> str:
        """
        transport URL which couldn't be detected right
        """
        return self._url
    
    @URL.setter
    def URL(self, value: str) -> None:
        self._url = value

    @property
    def SelectedFilter(self) -> str:
        """
        transport the preselected filter
        """
        return self._selected_filter
    
    @SelectedFilter.setter
    def SelectedFilter(self, value: str) -> None:
        self._selected_filter = value

    @property
    def DetectedFilter(self) -> str:
        """
        transport the real detected filter, which stands in conflict to the pre selected one
        """
        return self._detected_filter
    
    @DetectedFilter.setter
    def DetectedFilter(self, value: str) -> None:
        self._detected_filter = value


__all__ = ['AmbigousFilterRequest']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbcx
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_columns_supplier import XColumnsSupplier as XColumnsSupplier_f0600da9
from .x_data_descriptor_factory import XDataDescriptorFactory as XDataDescriptorFactory_46170fe5

class Index(XPropertySet_bc180bfa, XColumnsSupplier_f0600da9, XDataDescriptorFactory_46170fe5):
    """
    Service Class

    is used to specify the index for a database table.
    
    It refers to one or more columns of a table.
    
    Note:  All properties and columns of an index could by modified before they are appended to a table. In that case the service is a data descriptor.

    See Also:
        `API Index <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbcx_1_1Index.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbcx'
    __ooo_full_ns__: str = 'com.sun.star.sdbcx.Index'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Catalog(self) -> str:
        """
        is the name of the index catalog, may be empty.
        """
        ...

    @abstractproperty
    def IsClustered(self) -> bool:
        """
        indicates that the index is clustered.
        """
        ...

    @abstractproperty
    def IsPrimaryKeyIndex(self) -> bool:
        """
        indicates that the index is used for the primary key.
        """
        ...

    @abstractproperty
    def IsUnique(self) -> bool:
        """
        indicates that the index allow only unique values.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        is the name of the index.
        """
        ...


__all__ = ['Index']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_data_pilot_table import XDataPilotTable as XDataPilotTable_e0530ce3
if typing.TYPE_CHECKING:
    from .data_pilot_table_position_data import DataPilotTablePositionData as DataPilotTablePositionData_8a0c115a
    from ..table.cell_address import CellAddress as CellAddress_ae5f0b56
    from ..table.cell_range_address import CellRangeAddress as CellRangeAddress_ec450d43

class XDataPilotTable2(XDataPilotTable_e0530ce3):
    """
    additional methods to extend com.sun.star.sheet.XDataPilotTable.
    
    com.sun.star.sheet.XDataPilotTable2 extends the old com.sun.star.sheet.XDataPilotTable interface with additional methods.
    
    **since**
    
        OOo 3.0

    See Also:
        `API XDataPilotTable2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotTable2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XDataPilotTable2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XDataPilotTable2'

    @abstractmethod
    def getDrillDownData(self, aAddr: CellAddress_ae5f0b56) -> typing.Tuple[typing.Tuple[object, ...], ...]:
        """
        When the address of a cell within the result area is given, XDataPilotTable2.getDrillDownData() returns its drill-down output table that includes only those rows that contribute to the value of that cell.
        """
        ...
    @abstractmethod
    def getOutputRangeByType(self, nType: int) -> CellRangeAddress_ec450d43:
        """
        This method returns a different output range of a DataPilot table per specified output range type.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getPositionData(self, aAddr: CellAddress_ae5f0b56) -> DataPilotTablePositionData_8a0c115a:
        """
        Given a cell address, it returns the information about that cell.
        
        The type of information returned depends upon whether the cell is within the result area or column/row header area.
        """
        ...
    @abstractmethod
    def insertDrillDownSheet(self, aAddr: CellAddress_ae5f0b56) -> None:
        """
        This method inserts a new sheet to display the drill-down data for a specified result cell. A drill-down data for a result cell consists of a subset of rows from the original data source that contribute to the value displayed in that cell.
        
        The new sheet is always inserted to the immediate left of the current sheet where the DataPilot table is. Note that when the drill-down data is empty, no new sheet is inserted.
        """
        ...

__all__ = ['XDataPilotTable2']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.table


class BorderLineStyle(object):
    """
    Const Class


    See Also:
        `API BorderLineStyle <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1table_1_1BorderLineStyle.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.BorderLineStyle'
    __ooo_type_name__: str = 'const'

    NONE = 32767
    """
    No border line.
    """
    SOLID = 0
    """
    Solid border line.
    """
    DOTTED = 1
    """
    Dotted border line.
    """
    DASHED = 2
    """
    Dashed border line.
    """
    DOUBLE = 3
    """
    Double border line.
    
    Widths of the lines and the gap are all equal, and vary equally with the total width.
    """
    THINTHICK_SMALLGAP = 4
    """
    Double border line with a thin line outside and a thick line inside separated by a small gap.
    """
    THINTHICK_MEDIUMGAP = 5
    """
    Double border line with a thin line outside and a thick line inside separated by a medium gap.
    """
    THINTHICK_LARGEGAP = 6
    """
    Double border line with a thin line outside and a thick line inside separated by a large gap.
    """
    THICKTHIN_SMALLGAP = 7
    """
    Double border line with a thick line outside and a thin line inside separated by a small gap.
    """
    THICKTHIN_MEDIUMGAP = 8
    """
    Double border line with a thick line outside and a thin line inside separated by a medium gap.
    """
    THICKTHIN_LARGEGAP = 9
    """
    Double border line with a thick line outside and a thin line inside separated by a large gap.
    """
    EMBOSSED = 10
    """
    3D embossed border line.
    """
    ENGRAVED = 11
    """
    3D engraved border line.
    """
    OUTSET = 12
    """
    Outset border line.
    """
    INSET = 13
    """
    Inset border line.
    """
    FINE_DASHED = 14
    """
    Finely dashed border line.
    """
    DOUBLE_THIN = 15
    """
    Double border line consisting of two fixed thin lines separated by a variable gap.
    """
    DASH_DOT = 16
    """
    Line consisting of a repetition of one dash and one dot.
    """
    DASH_DOT_DOT = 17
    """
    Line consisting of a repetition of one dash and 2 dots.
    """
    BORDER_LINE_STYLE_MAX = 17
    """
    Maximum valid border line style value.
    """

__all__ = ['BorderLineStyle']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2
from __future__ import annotations
import typing
from abc import abstractmethod
from ..frame.x_model import XModel as XModel_7a6e095c
if typing.TYPE_CHECKING:
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
    from .x_chart_type_manager import XChartTypeManager as XChartTypeManager_6330df3
    from .x_diagram import XDiagram as XDiagram_96fe0a59
    from .data.x_data_provider import XDataProvider as XDataProvider_122f0e31

class XChartDocument(XModel_7a6e095c):
    """

    See Also:
        `API XChartDocument <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartDocument.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.XChartDocument'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart2.XChartDocument'

    @abstractmethod
    def createDefaultChart(self) -> None:
        """
        Creates a default chart type for a brand-new chart object.
        """
        ...
    @abstractmethod
    def createInternalDataProvider(self, bCloneExistingData: bool) -> None:
        """
        creates an internal com.sun.star.chart2.XDataProvider that is handled by the chart document itself.
        
        When the model is stored, the data provider will also be stored in a sub-storage.

        Raises:
            com.sun.star.util.CloseVetoException: ``CloseVetoException``
        """
        ...
    @abstractmethod
    def getChartTypeManager(self) -> XChartTypeManager_6330df3:
        """
        retrieves the component that is able to create different chart type templates (components of type ChartTypeTemplate)
        """
        ...
    @abstractmethod
    def getDataProvider(self) -> XDataProvider_122f0e31:
        """
        Returns the currently set data provider.
        
        This may be an internal one, if createInternalDataProvider() has been called before, or an external one if XDataReceiver.attachDataProvider() has been called.
        """
        ...
    @abstractmethod
    def getFirstDiagram(self) -> XDiagram_96fe0a59:
        """
        Notes: this is preliminary, we need an API that supports more than one diagram. The method name getDiagram exists in the css.chart API, so there is would be no way to choose either this or the other method from Basic (it would chose one or the other by random).
        """
        ...
    @abstractmethod
    def getPageBackground(self) -> XPropertySet_bc180bfa:
        """
        Gives access to the page background appearance.
        
        The area's extent is equal to the document size. If you want to access properties of the background area of a single diagram (the part where data points are actually plotted in), you have to get its wall. You can get the wall by calling XDiagram.getWall().
        """
        ...
    @abstractmethod
    def hasInternalDataProvider(self) -> bool:
        """
        This is the case directly after createInternalDataProvider() has been called, but this is not necessary. The chart can also create an internal data provider by other means, e.g. a call to com.sun.star.frame.XModel.initNew().
        """
        ...
    @abstractmethod
    def setChartTypeManager(self, xNewManager: XChartTypeManager_6330df3) -> None:
        """
        sets a new component that is able to create different chart type templates (components of type ChartTypeTemplate)
        """
        ...
    @abstractmethod
    def setFirstDiagram(self, xDiagram: XDiagram_96fe0a59) -> None:
        """
        Notes: this is preliminary, we need an API that supports more than one diagram. The method name setDiagram exists in the css.chart API, so there is would be no way to choose either this or the other method from Basic (it would chose one or the other by random).
        """
        ...

__all__ = ['XChartDocument']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_locale_data import XLocaleData as XLocaleData_9d100a6a
if typing.TYPE_CHECKING:
    from .currency2 import Currency2 as Currency2_89e809c5
    from ..lang.locale import Locale as Locale_70d308fa

class XLocaleData2(XLocaleData_9d100a6a):
    """
    Access locale specific data.
    
    Derived from com.sun.star.i18n.XLocaleData and provides an additional method to return a sequence of all com.sun.star.i18n.Currency2 elements available for that locale.
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API XLocaleData2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XLocaleData2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.XLocaleData2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.i18n.XLocaleData2'

    @abstractmethod
    def getAllCurrencies2(self, aLocale: Locale_70d308fa) -> typing.Tuple[Currency2_89e809c5, ...]:
        """
        returns all LC_CURRENCY currencies for a locale.
        """
        ...

__all__ = ['XLocaleData2']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n


class KNumberFormatUsage(object):
    """
    Const Class

    Category of number format code.

    See Also:
        `API KNumberFormatUsage <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1KNumberFormatUsage.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.KNumberFormatUsage'
    __ooo_type_name__: str = 'const'

    DATE = 1
    """
    Date format, for example, \"YYYY-MM-DD\".
    """
    TIME = 2
    """
    Time format, for example, \"HH:MM:SS\".
    """
    DATE_TIME = 3
    """
    Mixed date/time format, for example, \"YYYY-MM-DD HH:MM:SS\".
    """
    FIXED_NUMBER = 4
    """
    Numeric format, for example, \"#,##0.00\".
    """
    FRACTION_NUMBER = 5
    """
    Fractional format, for example, \"# ??/??\".
    """
    PERCENT_NUMBER = 6
    """
    Percent format, for example, \"0.00%\".
    """
    SCIENTIFIC_NUMBER = 7
    """
    Scientific format, for example, \"0.00E+00\".
    """
    CURRENCY = 8
    """
    Currency format, for example, \"#,##0.00 [$EUR]\".
    """

__all__ = ['KNumberFormatUsage']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..ucb.x_content import XContent as XContent_79db0975

class XQueryDefinition(XPropertySet_bc180bfa, XComponent_98dc0ab5, XContent_79db0975):
    """
    
    **since**
    
        LibreOffice 4.1

    See Also:
        `API XQueryDefinition <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XQueryDefinition.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.XQueryDefinition'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdb.XQueryDefinition'


__all__ = ['XQueryDefinition']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
import typing
from abc import abstractproperty
from ..drawing.shape import Shape as Shape_85cc09e5
from ..style.character_properties import CharacterProperties as CharacterProperties_1d4f0ef3
from ..xml.user_defined_attributes_supplier import UserDefinedAttributesSupplier as UserDefinedAttributesSupplier_9fbe1222
if typing.TYPE_CHECKING:
    from com.sun.star.chart.ChartLegendPosition import ChartLegendPositionProto

class ChartLegend(Shape_85cc09e5, CharacterProperties_1d4f0ef3, UserDefinedAttributesSupplier_9fbe1222):
    """
    Service Class

    specifies the legend of a chart.
    
    The text/font properties which are specified in the service com.sun.star.drawing.Shape correlate to all text objects inside the legend.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API ChartLegend <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1ChartLegend.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.ChartLegend'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Alignment(self) -> ChartLegendPositionProto:
        """
        determines the alignment of the legend relative to the diagram.
        """
        ...

    @abstractproperty
    def AutomaticPosition(self) -> bool:
        """
        If this property is TRUE the position is calculated by the application automatically.
        
        Setting this property to false will have no effect. Instead use the interface com.sun.star.drawing.XShape to set a concrete position.
        """
        ...


__all__ = ['ChartLegend']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.beans
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing


class PropertySetInfoChangeEvent(EventObject_a3d70b03):
    """
    Struct Class

    gets delivered whenever an XPropertySetInfo is changed.
    
    A PropertySetInfoChangeEvent object is sent to XPropertySetInfoChangeListeners.

    See Also:
        `API PropertySetInfoChangeEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1beans_1_1PropertySetInfoChangeEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.PropertySetInfoChangeEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.beans.PropertySetInfoChangeEvent'
    """Literal Constant ``com.sun.star.beans.PropertySetInfoChangeEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Name: typing.Optional[str] = '', Handle: typing.Optional[int] = 0, Reason: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Name (str, optional): Name value.
            Handle (int, optional): Handle value.
            Reason (int, optional): Reason value.
        """

        if isinstance(Source, PropertySetInfoChangeEvent):
            oth: PropertySetInfoChangeEvent = Source
            self.Source = oth.Source
            self.Name = oth.Name
            self.Handle = oth.Handle
            self.Reason = oth.Reason
            return

        kargs = {
            "Source": Source,
            "Name": Name,
            "Handle": Handle,
            "Reason": Reason,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._name = kwargs["Name"]
        self._handle = kwargs["Handle"]
        self._reason = kwargs["Reason"]
        inst_keys = ('Name', 'Handle', 'Reason')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def Name(self) -> str:
        """
        contains the name of the property.
        """
        return self._name

    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value

    @property
    def Handle(self) -> int:
        """
        contains the implementation handle for the property.
        
        May be -1 if the implementation has no handle.
        """
        return self._handle

    @Handle.setter
    def Handle(self, value: int) -> None:
        self._handle = value

    @property
    def Reason(self) -> int:
        """
        contains the reason for the event.
        """
        return self._reason

    @Reason.setter
    def Reason(self, value: int) -> None:
        self._reason = value


__all__ = ['PropertySetInfoChangeEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class ReferenceFieldPart(metaclass=UnoConstMeta, type_name="com.sun.star.text.ReferenceFieldPart", name_space="com.sun.star.text"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.text.ReferenceFieldPart``"""
        pass

    class ReferenceFieldPartEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.text.ReferenceFieldPart", name_space="com.sun.star.text"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.text.ReferenceFieldPart`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.text import ReferenceFieldPart as ReferenceFieldPart
    else:
        # keep document generators happy
        from ...lo.text.reference_field_part import ReferenceFieldPart as ReferenceFieldPart

    class ReferenceFieldPartEnum(IntEnum):
        """
        Enum of Const Class ReferenceFieldPart

        These constants define how the reference position is displayed in reference text fields.
        
        **since**
        
            OOo 3.0
        """
        PAGE = ReferenceFieldPart.PAGE
        """
        The page number is displayed using Arabic numbers.
        """
        CHAPTER = ReferenceFieldPart.CHAPTER
        """
        The number of the chapter is displayed.
        """
        TEXT = ReferenceFieldPart.TEXT
        """
        The reference text is displayed.
        
        If the source of the reference is a sequence field, then the complete text of the paragraph is displayed. This is useful to reference to captions.
        """
        UP_DOWN = ReferenceFieldPart.UP_DOWN
        """
        The reference is displayed as one of the (localized) words, \"above\" or \"below\".
        """
        PAGE_DESC = ReferenceFieldPart.PAGE_DESC
        """
        The page number is displayed using the numbering type defined in the page style of the reference position.
        """
        CATEGORY_AND_NUMBER = ReferenceFieldPart.CATEGORY_AND_NUMBER
        """
        The category and the number of a caption is displayed.
        
        This option is only valid if the source of the reference is a sequence field.
        """
        ONLY_CAPTION = ReferenceFieldPart.ONLY_CAPTION
        """
        The caption text of a caption is displayed.
        
        This option is only valid if the source of the reference is a sequence field.
        """
        ONLY_SEQUENCE_NUMBER = ReferenceFieldPart.ONLY_SEQUENCE_NUMBER
        """
        The number of a sequence field is displayed.
        
        This option is only valid if the source of the reference is a sequence field.
        """
        NUMBER = ReferenceFieldPart.NUMBER
        """
        The numbering label and depending of the reference field context numbering labels of superior list levels of the reference are displayed.
        
        This option is only valid, if the source of the reference is a bookmark or a set reference.
        
        The contents of the list label of the paragraph, at which the bookmark respectively the set reference starts - named \"referenced item\" in the following - is displayed. To unambiguous identify the referenced item at the document position of the reference text field, the content of all needed superior levels are added in front. The needed superior levels of the referenced item are the ones, which differ from the superior levels of the document position of the reference text field. Additional condition, which suppresses the addition of a superior level's list label content: The list label of the referenced item can already contain numbers of a superior levels. Assume X be the level of the most superior level, then no list label content of superior levels greater or equal than X are added. If the referenced item isn't numbered, nothing is displayed.
        
        **since**
        
            OOo 3.0
        """
        NUMBER_NO_CONTEXT = ReferenceFieldPart.NUMBER_NO_CONTEXT
        """
        The numbering label of the reference is displayed.
        
        This option is only valid, if the source of the reference is a bookmark or a set reference.
        
        The contents of the list label of the paragraph, at which the bookmark respectively the set reference starts, is displayed. If this paragraph isn't numbered, nothing is displayed.
        
        **since**
        
            OOo 3.0
        """
        NUMBER_FULL_CONTEXT = ReferenceFieldPart.NUMBER_FULL_CONTEXT
        """
        The numbering label and numbering labels of superior list levels of the reference are displayed.
        
        This option is only valid, if the source of the reference is a bookmark or a set reference.
        
        The contents of the list label of the paragraph, at which the bookmark respectively the set reference starts - named \"referenced item\" in the following - is displayed and the contents of all list labels of superior levels are added in front of it. Additional condition, which suppresses the addition of a superior level's list label content: The list label of the referenced item can already contain numbers of a superior levels. Assume X be the level of the most superior level, then no list label content of superior levels greater or equal than X are added. If the referenced item is numbered nothing is displayed.
        
        **since**
        
            OOo 3.0
        """

__all__ = ['ReferenceFieldPart', 'ReferenceFieldPartEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.beans
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .property_state import PropertyState as PropertyState_c97b0c77


class PropertyStateChangeEvent(EventObject_a3d70b03):
    """
    Struct Class

    is delivered whenever the state of a \"bound\" property is changed.
    
    It is sent as an argument to the method of XPropertyStateChangeListener.
    
    Normally these events are accompanied by the name, and the old and new values of the changed property.
    
    Void values may be provided for the old and new values if their true values are not known.

    See Also:
        `API PropertyStateChangeEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1beans_1_1PropertyStateChangeEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.PropertyStateChangeEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.beans.PropertyStateChangeEvent'
    """Literal Constant ``com.sun.star.beans.PropertyStateChangeEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, PropertyName: typing.Optional[str] = '', PropertyHandle: typing.Optional[int] = 0, OldValue: typing.Optional[PropertyState_c97b0c77] = PropertyState_c97b0c77.DIRECT_VALUE, NewValue: typing.Optional[PropertyState_c97b0c77] = PropertyState_c97b0c77.DIRECT_VALUE) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            PropertyName (str, optional): PropertyName value.
            PropertyHandle (int, optional): PropertyHandle value.
            OldValue (PropertyState, optional): OldValue value.
            NewValue (PropertyState, optional): NewValue value.
        """

        if isinstance(Source, PropertyStateChangeEvent):
            oth: PropertyStateChangeEvent = Source
            self.Source = oth.Source
            self.PropertyName = oth.PropertyName
            self.PropertyHandle = oth.PropertyHandle
            self.OldValue = oth.OldValue
            self.NewValue = oth.NewValue
            return

        kargs = {
            "Source": Source,
            "PropertyName": PropertyName,
            "PropertyHandle": PropertyHandle,
            "OldValue": OldValue,
            "NewValue": NewValue,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._property_name = kwargs["PropertyName"]
        self._property_handle = kwargs["PropertyHandle"]
        self._old_value = kwargs["OldValue"]
        self._new_value = kwargs["NewValue"]
        inst_keys = ('PropertyName', 'PropertyHandle', 'OldValue', 'NewValue')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def PropertyName(self) -> str:
        """
        specifies the name of the property which changes its value.
        
        This name identifies the property uniquely within an XPropertySet. Upper and lower case are distinguished.
        """
        return self._property_name

    @PropertyName.setter
    def PropertyName(self, value: str) -> None:
        self._property_name = value

    @property
    def PropertyHandle(self) -> int:
        """
        contains the implementation handle for the property.
        
        It may be -1 if the implementation has no handle. You can use this handle to get values from the XFastPropertySet interface.
        """
        return self._property_handle

    @PropertyHandle.setter
    def PropertyHandle(self, value: int) -> None:
        self._property_handle = value

    @property
    def OldValue(self) -> PropertyState_c97b0c77:
        """
        contains the old value of the property.
        """
        return self._old_value

    @OldValue.setter
    def OldValue(self, value: PropertyState_c97b0c77) -> None:
        self._old_value = value

    @property
    def NewValue(self) -> PropertyState_c97b0c77:
        """
        contains the new value of the property.
        """
        return self._new_value

    @NewValue.setter
    def NewValue(self, value: PropertyState_c97b0c77) -> None:
        self._new_value = value


__all__ = ['PropertyStateChangeEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class TransliterationModules(metaclass=UnoEnumMeta, type_name="com.sun.star.i18n.TransliterationModules", name_space="com.sun.star.i18n"):
        """Dynamically created class that represents ``com.sun.star.i18n.TransliterationModules`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.i18n.TransliterationModules import END_OF_MODULE as TRANSLITERATION_MODULES_END_OF_MODULE
        from com.sun.star.i18n.TransliterationModules import FULLWIDTH_HALFWIDTH as TRANSLITERATION_MODULES_FULLWIDTH_HALFWIDTH
        from com.sun.star.i18n.TransliterationModules import HALFWIDTH_FULLWIDTH as TRANSLITERATION_MODULES_HALFWIDTH_FULLWIDTH
        from com.sun.star.i18n.TransliterationModules import HIRAGANA_KATAKANA as TRANSLITERATION_MODULES_HIRAGANA_KATAKANA
        from com.sun.star.i18n.TransliterationModules import IGNORE_CASE as TRANSLITERATION_MODULES_IGNORE_CASE
        from com.sun.star.i18n.TransliterationModules import IGNORE_KANA as TRANSLITERATION_MODULES_IGNORE_KANA
        from com.sun.star.i18n.TransliterationModules import IGNORE_MASK as TRANSLITERATION_MODULES_IGNORE_MASK
        from com.sun.star.i18n.TransliterationModules import IGNORE_WIDTH as TRANSLITERATION_MODULES_IGNORE_WIDTH
        from com.sun.star.i18n.TransliterationModules import IgnoreBaFa_ja_JP as TRANSLITERATION_MODULES_IgnoreBaFa_ja_JP
        from com.sun.star.i18n.TransliterationModules import IgnoreHyuByu_ja_JP as TRANSLITERATION_MODULES_IgnoreHyuByu_ja_JP
        from com.sun.star.i18n.TransliterationModules import IgnoreIandEfollowedByYa_ja_JP as TRANSLITERATION_MODULES_IgnoreIandEfollowedByYa_ja_JP
        from com.sun.star.i18n.TransliterationModules import IgnoreIterationMark_ja_JP as TRANSLITERATION_MODULES_IgnoreIterationMark_ja_JP
        from com.sun.star.i18n.TransliterationModules import IgnoreKiKuFollowedBySa_ja_JP as TRANSLITERATION_MODULES_IgnoreKiKuFollowedBySa_ja_JP
        from com.sun.star.i18n.TransliterationModules import IgnoreMiddleDot_ja_JP as TRANSLITERATION_MODULES_IgnoreMiddleDot_ja_JP
        from com.sun.star.i18n.TransliterationModules import IgnoreMinusSign_ja_JP as TRANSLITERATION_MODULES_IgnoreMinusSign_ja_JP
        from com.sun.star.i18n.TransliterationModules import IgnoreProlongedSoundMark_ja_JP as TRANSLITERATION_MODULES_IgnoreProlongedSoundMark_ja_JP
        from com.sun.star.i18n.TransliterationModules import IgnoreSeZe_ja_JP as TRANSLITERATION_MODULES_IgnoreSeZe_ja_JP
        from com.sun.star.i18n.TransliterationModules import IgnoreSeparator_ja_JP as TRANSLITERATION_MODULES_IgnoreSeparator_ja_JP
        from com.sun.star.i18n.TransliterationModules import IgnoreSize_ja_JP as TRANSLITERATION_MODULES_IgnoreSize_ja_JP
        from com.sun.star.i18n.TransliterationModules import IgnoreSpace_ja_JP as TRANSLITERATION_MODULES_IgnoreSpace_ja_JP
        from com.sun.star.i18n.TransliterationModules import IgnoreTiJi_ja_JP as TRANSLITERATION_MODULES_IgnoreTiJi_ja_JP
        from com.sun.star.i18n.TransliterationModules import IgnoreTraditionalKana_ja_JP as TRANSLITERATION_MODULES_IgnoreTraditionalKana_ja_JP
        from com.sun.star.i18n.TransliterationModules import IgnoreTraditionalKanji_ja_JP as TRANSLITERATION_MODULES_IgnoreTraditionalKanji_ja_JP
        from com.sun.star.i18n.TransliterationModules import IgnoreZiZu_ja_JP as TRANSLITERATION_MODULES_IgnoreZiZu_ja_JP
        from com.sun.star.i18n.TransliterationModules import KATAKANA_HIRAGANA as TRANSLITERATION_MODULES_KATAKANA_HIRAGANA
        from com.sun.star.i18n.TransliterationModules import LOWERCASE_UPPERCASE as TRANSLITERATION_MODULES_LOWERCASE_UPPERCASE
        from com.sun.star.i18n.TransliterationModules import LargeToSmall_ja_JP as TRANSLITERATION_MODULES_LargeToSmall_ja_JP
        from com.sun.star.i18n.TransliterationModules import NON_IGNORE_MASK as TRANSLITERATION_MODULES_NON_IGNORE_MASK
        from com.sun.star.i18n.TransliterationModules import NumToTextFormalHangul_ko as TRANSLITERATION_MODULES_NumToTextFormalHangul_ko
        from com.sun.star.i18n.TransliterationModules import NumToTextFormalLower_ko as TRANSLITERATION_MODULES_NumToTextFormalLower_ko
        from com.sun.star.i18n.TransliterationModules import NumToTextFormalUpper_ko as TRANSLITERATION_MODULES_NumToTextFormalUpper_ko
        from com.sun.star.i18n.TransliterationModules import NumToTextLower_zh_CN as TRANSLITERATION_MODULES_NumToTextLower_zh_CN
        from com.sun.star.i18n.TransliterationModules import NumToTextLower_zh_TW as TRANSLITERATION_MODULES_NumToTextLower_zh_TW
        from com.sun.star.i18n.TransliterationModules import NumToTextUpper_zh_CN as TRANSLITERATION_MODULES_NumToTextUpper_zh_CN
        from com.sun.star.i18n.TransliterationModules import NumToTextUpper_zh_TW as TRANSLITERATION_MODULES_NumToTextUpper_zh_TW
        from com.sun.star.i18n.TransliterationModules import SmallToLarge_ja_JP as TRANSLITERATION_MODULES_SmallToLarge_ja_JP
        from com.sun.star.i18n.TransliterationModules import UPPERCASE_LOWERCASE as TRANSLITERATION_MODULES_UPPERCASE_LOWERCASE

        class TransliterationModules(uno.Enum):
            """
            Enum Class


            See Also:
                `API TransliterationModules <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n.html#a9c57a33dd757352c82923f4c7f6cf93c>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.i18n.TransliterationModules', value)

            __ooo_ns__: str = 'com.sun.star.i18n'
            __ooo_full_ns__: str = 'com.sun.star.i18n.TransliterationModules'
            __ooo_type_name__: str = 'enum'

            END_OF_MODULE = TRANSLITERATION_MODULES_END_OF_MODULE
            """
            """
            FULLWIDTH_HALFWIDTH = TRANSLITERATION_MODULES_FULLWIDTH_HALFWIDTH
            """
            Transliterate a string from full width character to half width character.
            """
            HALFWIDTH_FULLWIDTH = TRANSLITERATION_MODULES_HALFWIDTH_FULLWIDTH
            """
            Transliterate a string from half width character to full width character.
            """
            HIRAGANA_KATAKANA = TRANSLITERATION_MODULES_HIRAGANA_KATAKANA
            """
            Transliterate a Japanese string from Hiragana to Katakana.
            """
            IGNORE_CASE = TRANSLITERATION_MODULES_IGNORE_CASE
            """
            Ignore case when comparing strings by transliteration service.
            """
            IGNORE_KANA = TRANSLITERATION_MODULES_IGNORE_KANA
            """
            Ignore Hiragana and Katakana when comparing strings by transliteration service.
            """
            IGNORE_MASK = TRANSLITERATION_MODULES_IGNORE_MASK
            """
            """
            IGNORE_WIDTH = TRANSLITERATION_MODULES_IGNORE_WIDTH
            """
            Ignore full width and half width character when comparing strings by transliteration service.

            Ignore full width and half width characters when comparing strings by transliteration service.
            """
            IgnoreBaFa_ja_JP = TRANSLITERATION_MODULES_IgnoreBaFa_ja_JP
            """
            Ignore Katakana and Hiragana Ba/Gua and Ha/Fa in Japanese fuzzy search.
            """
            IgnoreHyuByu_ja_JP = TRANSLITERATION_MODULES_IgnoreHyuByu_ja_JP
            """
            Ignore Katakana and Hiragana Hyu/Fyu and Byu/Gyu in Japanese fuzzy search.
            """
            IgnoreIandEfollowedByYa_ja_JP = TRANSLITERATION_MODULES_IgnoreIandEfollowedByYa_ja_JP
            """
            Ignore Katakana YA/A which follows the character in either I or E row in Japanese fuzzy search.

            Ignore Katakana YA/A following the character in either I or E row in Japanese fuzzy search.
            """
            IgnoreIterationMark_ja_JP = TRANSLITERATION_MODULES_IgnoreIterationMark_ja_JP
            """
            Ignore Hiragana and Katakana iteration mark in Japanese fuzzy search.
            """
            IgnoreKiKuFollowedBySa_ja_JP = TRANSLITERATION_MODULES_IgnoreKiKuFollowedBySa_ja_JP
            """
            Ignore Katakana KI/KU which follows the character in SA column in Japanese fuzzy search.

            Ignore Katakana KI/KU following the character in SA column in Japanese fuzzy search.
            """
            IgnoreMiddleDot_ja_JP = TRANSLITERATION_MODULES_IgnoreMiddleDot_ja_JP
            """
            Ignore middle dot in Japanese fuzzy search.
            """
            IgnoreMinusSign_ja_JP = TRANSLITERATION_MODULES_IgnoreMinusSign_ja_JP
            """
            Ignore dash or minus sign in Japanese fuzzy search.
            """
            IgnoreProlongedSoundMark_ja_JP = TRANSLITERATION_MODULES_IgnoreProlongedSoundMark_ja_JP
            """
            Ignore Japanese prolonged sound mark in Japanese fuzzy search.
            """
            IgnoreSeZe_ja_JP = TRANSLITERATION_MODULES_IgnoreSeZe_ja_JP
            """
            Ignore Katakana and Hiragana Se/Sye and Ze/Je in Japanese fuzzy search.
            """
            IgnoreSeparator_ja_JP = TRANSLITERATION_MODULES_IgnoreSeparator_ja_JP
            """
            Ignore separator punctuations in Japanese fuzzy search.
            """
            IgnoreSize_ja_JP = TRANSLITERATION_MODULES_IgnoreSize_ja_JP
            """
            Ignore Japanese normal and small sized character in Japanese fuzzy search.
            """
            IgnoreSpace_ja_JP = TRANSLITERATION_MODULES_IgnoreSpace_ja_JP
            """
            Ignore white space characters, include space, TAB, return, etc. in Japanese fuzzy search.
            """
            IgnoreTiJi_ja_JP = TRANSLITERATION_MODULES_IgnoreTiJi_ja_JP
            """
            Ignore Katakana and Hiragana Tsui/Tea/Ti and Dyi/Ji in Japanese fuzzy search.
            """
            IgnoreTraditionalKana_ja_JP = TRANSLITERATION_MODULES_IgnoreTraditionalKana_ja_JP
            """
            Ignore Japanese traditional Katakana and Hiragana character in Japanese fuzzy search.

            Ignore Japanese traditional Katakana and Hiragana characters in Japanese fuzzy search.
            """
            IgnoreTraditionalKanji_ja_JP = TRANSLITERATION_MODULES_IgnoreTraditionalKanji_ja_JP
            """
            Ignore Japanese traditional Kanji character in Japanese fuzzy search.

            Ignore Japanese traditional Kanji characters in Japanese fuzzy search.
            """
            IgnoreZiZu_ja_JP = TRANSLITERATION_MODULES_IgnoreZiZu_ja_JP
            """
            Ignore Katakana and Hiragana Zi/Zi and Zu/Zu in Japanese fuzzy search.
            """
            KATAKANA_HIRAGANA = TRANSLITERATION_MODULES_KATAKANA_HIRAGANA
            """
            Transliterate a Japanese string from Katakana to Hiragana.
            """
            LOWERCASE_UPPERCASE = TRANSLITERATION_MODULES_LOWERCASE_UPPERCASE
            """
            Transliterate a string from lower case to upper case.
            """
            LargeToSmall_ja_JP = TRANSLITERATION_MODULES_LargeToSmall_ja_JP
            """
            transliterate Japanese normal sized character to small sized character
            """
            NON_IGNORE_MASK = TRANSLITERATION_MODULES_NON_IGNORE_MASK
            """
            """
            NumToTextFormalHangul_ko = TRANSLITERATION_MODULES_NumToTextFormalHangul_ko
            """
            Transliterate an ASCII number string to formal Korean Hangul number string in spellout format.
            """
            NumToTextFormalLower_ko = TRANSLITERATION_MODULES_NumToTextFormalLower_ko
            """
            Transliterate an ASCII number string to formal Korean Hanja lower case number string in spellout format.
            """
            NumToTextFormalUpper_ko = TRANSLITERATION_MODULES_NumToTextFormalUpper_ko
            """
            Transliterate an ASCII number string to formal Korean Hanja upper case number string in spellout format.
            """
            NumToTextLower_zh_CN = TRANSLITERATION_MODULES_NumToTextLower_zh_CN
            """
            Transliterate an ASCII number string to Simplified Chinese lower case number string in spellout format.
            """
            NumToTextLower_zh_TW = TRANSLITERATION_MODULES_NumToTextLower_zh_TW
            """
            Transliterate an ASCII number string to Traditional Chinese lower case number string in spellout format.
            """
            NumToTextUpper_zh_CN = TRANSLITERATION_MODULES_NumToTextUpper_zh_CN
            """
            Transliterate an ASCII number string to Simplified Chinese upper case number string in spellout format.
            """
            NumToTextUpper_zh_TW = TRANSLITERATION_MODULES_NumToTextUpper_zh_TW
            """
            Transliterate an ASCII number string to Traditional Chinese upper case number string in spellout format.
            """
            SmallToLarge_ja_JP = TRANSLITERATION_MODULES_SmallToLarge_ja_JP
            """
            transliterate Japanese small sized character to normal sized character
            """
            UPPERCASE_LOWERCASE = TRANSLITERATION_MODULES_UPPERCASE_LOWERCASE
            """
            Transliterate a string from upper case to lower case.
            """
    else:
        # keep document generators happy
        from ...lo.i18n.transliteration_modules import TransliterationModules as TransliterationModules


__all__ = ['TransliterationModules']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.configuration.backend
from __future__ import annotations
from .x_backend import XBackend as XBackend_6ce81076
from .x_backend_entities import XBackendEntities as XBackendEntities_fecf13bb
from .x_schema_supplier import XSchemaSupplier as XSchemaSupplier_eca11373

class Backend(XBackend_6ce81076, XBackendEntities_fecf13bb, XSchemaSupplier_eca11373):
    """
    Service Class

    provides access to a configuration database composed of one or more storage backends containing settings used by software modules.
    
    Configuration data is organized into layers which are selected by components and entities.
    
    Components are characterized by configuration schemas. A component contains configuration data for a particular application domain or software module.
    
    Entities are organized hierarchically in organizations, groups, roles and individual users. Each element of the associated hierarchy corresponds to a layer that applies to an entity.
    
    A layer contains data for multiple components associated to a single entity.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API Backend <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1Backend.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration.backend'
    __ooo_full_ns__: str = 'com.sun.star.configuration.backend.Backend'
    __ooo_type_name__: str = 'service'


__all__ = ['Backend']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt


class SystemPointer(object):
    """
    Const Class

    specifies the shape of a mouse pointer.

    See Also:
        `API SystemPointer <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1SystemPointer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.SystemPointer'
    __ooo_type_name__: str = 'const'

    ARROW = 0
    """
    specifies the normal arrow-like mouse pointer.
    """
    INVISIBLE = 1
    """
    specifies an invisible mouse pointer.
    """
    WAIT = 2
    """
    specifies a waiting symbol as a mouse pointer (for example hourglass).
    """
    TEXT = 3
    """
    specifies a mouse pointer for text (cursor-like).
    """
    HELP = 4
    """
    specifies a mouse pointer for on-line help.
    """
    CROSS = 5
    """
    specifies a cross as a mouse pointer.
    """
    MOVE = 6
    """
    specifies a mouse pointer which symbolizes movement.
    """
    NSIZE = 7
    """
    specifies a mouse pointer which symbolizes resizing for a top border.
    """
    SSIZE = 8
    """
    specifies a mouse pointer which symbolizes resizing for a bottom border.
    """
    WSIZE = 9
    """
    specifies a mouse pointer which symbolizes resizing for a left border.
    """
    ESIZE = 10
    """
    specifies a mouse pointer which symbolizes resizing for a right border.
    """
    NWSIZE = 11
    """
    specifies a mouse pointer which symbolizes resizing for the top-left corner.
    """
    NESIZE = 12
    """
    specifies a mouse pointer which symbolizes resizing for the top-right corner.
    """
    SWSIZE = 13
    """
    specifies a mouse pointer which symbolizes resizing for the bottom-left corner.
    """
    SESIZE = 14
    """
    specifies a mouse pointer which symbolizes resizing for the bottom-right corner.
    """
    WINDOW_NSIZE = 15
    """
    specifies a mouse pointer which symbolizes window resizing for a top border.
    """
    WINDOW_SSIZE = 16
    """
    specifies a mouse pointer which symbolizes window resizing for a bottom border.
    """
    WINDOW_WSIZE = 17
    """
    specifies a mouse pointer which symbolizes window resizing for a left border.
    """
    WINDOW_ESIZE = 18
    """
    specifies a mouse pointer which symbolizes window resizing for a right border.
    """
    WINDOW_NWSIZE = 19
    """
    specifies a mouse pointer which symbolizes window resizing for the top-left corner.
    """
    WINDOW_NESIZE = 20
    """
    specifies a mouse pointer which symbolizes window resizing for the top-right corner.
    """
    WINDOW_SWSIZE = 21
    """
    specifies a mouse pointer which symbolizes window resizing for the bottom-left corner.
    """
    WINDOW_SESIZE = 22
    """
    specifies a mouse pointer which symbolizes window resizing for the bottom-right corner.
    """
    HSPLIT = 23
    """
    specifies a mouse pointer which symbolizes horizontal splitting.
    """
    VSPLIT = 24
    """
    specifies a mouse pointer which symbolizes vertical splitting.
    """
    HSIZEBAR = 25
    """
    specifies a mouse pointer which symbolizes horizontal resizing.
    """
    VSIZEBAR = 26
    """
    specifies a mouse pointer which symbolizes vertical resizing.
    """
    HAND = 27
    """
    specifies a hand symbol as mouse pointer.
    """
    REFHAND = 28
    """
    specifies a pointing hand symbol as mouse pointer.
    """
    PEN = 29
    """
    specifies a pen symbol as mouse pointer.
    """
    MAGNIFY = 30
    """
    specifies a magnify symbol as mouse pointer.
    """
    FILL = 31
    """
    specifies a fill symbol as mouse pointer.
    """
    ROTATE = 32
    """
    specifies a rotate symbol as mouse pointer.
    """
    HSHEAR = 33
    """
    specifies a horizontal shear symbol as mouse pointer.
    """
    VSHEAR = 34
    """
    specifies a vertical shear symbol as mouse pointer.
    """
    MIRROR = 35
    """
    specifies a mirror symbol as mouse pointer.
    """
    CROOK = 36
    """
    specifies a crook symbol as mouse pointer.
    """
    CROP = 37
    """
    specifies a crop symbol as mouse pointer.
    """
    MOVEPOINT = 38
    """
    specifies a mouse pointer which symbolizes moving a point.
    """
    MOVEBEZIERWEIGHT = 39
    """
    specifies a mouse pointer which symbolizes moving a Bezier weight.
    """
    MOVEDATA = 40
    """
    specifies a mouse pointer which symbolizes moving data.
    """
    COPYDATA = 41
    """
    specifies a mouse pointer which symbolizes copying data.
    """
    LINKDATA = 42
    """
    specifies a mouse pointer which symbolizes linking data.
    """
    MOVEDATALINK = 43
    """
    specifies a mouse pointer which symbolizes moving a data link.
    """
    COPYDATALINK = 44
    """
    specifies a mouse pointer which symbolizes copying a data link.
    """
    MOVEFILE = 45
    """
    specifies a mouse pointer which symbolizes moving a file.
    """
    COPYFILE = 46
    """
    specifies a mouse pointer which symbolizes copying a file.
    """
    LINKFILE = 47
    """
    specifies a mouse pointer which symbolizes linking a file.
    """
    MOVEFILELINK = 48
    """
    specifies a mouse pointer which symbolizes moving a file link.
    """
    COPYFILELINK = 49
    """
    specifies a mouse pointer which symbolizes copying a file link.
    """
    MOVEFILES = 50
    """
    specifies a mouse pointer which symbolizes moving multiple files.
    """
    COPYFILES = 51
    """
    specifies a mouse pointer which symbolizes copying multiple files.
    """
    NOTALLOWED = 52
    """
    specifies a mouse pointer which symbolizes \"not allowed\".
    """
    DRAW_LINE = 53
    """
    specifies a mouse pointer which symbolizes drawing a line.
    """
    DRAW_RECT = 54
    """
    specifies a mouse pointer which symbolizes drawing a rectangle.
    """
    DRAW_POLYGON = 55
    """
    specifies a mouse pointer which symbolizes drawing a polygon.
    """
    DRAW_BEZIER = 56
    """
    specifies a mouse pointer which symbolizes drawing a Bezier.
    """
    DRAW_ARC = 57
    """
    specifies a mouse pointer which symbolizes drawing an arc.
    """
    DRAW_PIE = 58
    """
    specifies a mouse pointer which symbolizes drawing a pie.
    """
    DRAW_CIRCLECUT = 59
    """
    specifies a mouse pointer which symbolizes drawing a circle cut.
    """
    DRAW_ELLIPSE = 60
    """
    specifies a mouse pointer which symbolizes drawing an ellipse.
    """
    DRAW_FREEHAND = 61
    """
    specifies a mouse pointer which symbolizes drawing free handed.
    """
    DRAW_CONNECT = 62
    """
    specifies a mouse pointer which symbolizes drawing a connector.
    """
    DRAW_TEXT = 63
    """
    specifies a mouse pointer which symbolizes drawing text.
    """
    DRAW_CAPTION = 64
    """
    specifies a mouse pointer which symbolizes drawing a text caption.
    """
    CHART = 65
    """
    specifies a mouse pointer which symbolizes a chart.
    """
    DETECTIVE = 66
    """
    specifies a mouse pointer which symbolizes a detective.
    """
    PIVOT_COL = 67
    """
    specifies a mouse pointer which symbolizes a pivot column.
    """
    PIVOT_ROW = 68
    """
    specifies a mouse pointer which symbolizes a pivot row.
    """
    PIVOT_FIELD = 69
    """
    specifies a mouse pointer which symbolizes a pivot field.
    """
    CHAIN = 70
    """
    specifies a mouse pointer which symbolizes a chain.
    """
    CHAIN_NOTALLOWED = 71
    """
    specifies a mouse pointer which symbolizes \"chaining not allowed\".
    """

__all__ = ['SystemPointer']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing.framework
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .x_resource_id import XResourceId as XResourceId_5be3103d


class TabBarButton(object):
    """
    Struct Class

    Descriptor of a tab bar button.
    
    Tab bar buttons are typically used to offer the user the choice between different views to be displayed in one pane.
    
    For identification only the ResourceId is used, so for some methods of the XTabBar interface only the ResourceId member is evaluated.

    See Also:
        `API TabBarButton <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1framework_1_1TabBarButton.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.TabBarButton'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.drawing.framework.TabBarButton'
    """Literal Constant ``com.sun.star.drawing.framework.TabBarButton``"""

    def __init__(self, ButtonLabel: typing.Optional[str] = '', HelpText: typing.Optional[str] = '', ResourceId: typing.Optional[XResourceId_5be3103d] = None) -> None:
        """
        Constructor

        Arguments:
            ButtonLabel (str, optional): ButtonLabel value.
            HelpText (str, optional): HelpText value.
            ResourceId (XResourceId, optional): ResourceId value.
        """
        super().__init__()

        if isinstance(ButtonLabel, TabBarButton):
            oth: TabBarButton = ButtonLabel
            self.ButtonLabel = oth.ButtonLabel
            self.HelpText = oth.HelpText
            self.ResourceId = oth.ResourceId
            return

        kargs = {
            "ButtonLabel": ButtonLabel,
            "HelpText": HelpText,
            "ResourceId": ResourceId,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._button_label = kwargs["ButtonLabel"]
        self._help_text = kwargs["HelpText"]
        self._resource_id = kwargs["ResourceId"]


    @property
    def ButtonLabel(self) -> str:
        """
        This label is displayed on the UI as button text.
        
        The label is expected to be localized.
        """
        return self._button_label

    @ButtonLabel.setter
    def ButtonLabel(self, value: str) -> None:
        self._button_label = value

    @property
    def HelpText(self) -> str:
        """
        The localized help text that may be displayed in a tool tip.
        """
        return self._help_text

    @HelpText.setter
    def HelpText(self, value: str) -> None:
        self._help_text = value

    @property
    def ResourceId(self) -> XResourceId_5be3103d:
        """
        XResourceId object of the resource that is requested to be displayed when the tab bar button is activated.
        
        For some methods of the XTabBar interface only this member is evaluated. That is because only this member is used to identify a tab bar button.
        """
        return self._resource_id

    @ResourceId.setter
    def ResourceId(self, value: XResourceId_5be3103d) -> None:
        self._resource_id = value


__all__ = ['TabBarButton']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.i18n.TransliterationModulesNew import TransliterationModulesNewProto

class TransliterationModulesNew(Enum):
    """
    Enum Class


    See Also:
        `API TransliterationModulesNew <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n.html#a436afb2c972c4d40d888b71482e93020>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.TransliterationModulesNew'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.i18n.TransliterationModulesNew'

    CharToNumHangul_ko = cast("TransliterationModulesNewProto", 'CharToNumHangul_ko')
    """
    Transliterate a Korean Hangul number string to ASCII number string.
    """
    CharToNumLower_ko = cast("TransliterationModulesNewProto", 'CharToNumLower_ko')
    """
    Transliterate a Korean Hanja lower case number string to ASCII number string.
    """
    CharToNumLower_zh_CN = cast("TransliterationModulesNewProto", 'CharToNumLower_zh_CN')
    """
    Transliterate a Simplified Chinese lower case number string to ASCII number string.
    """
    CharToNumLower_zh_TW = cast("TransliterationModulesNewProto", 'CharToNumLower_zh_TW')
    """
    Transliterate a Traditional Chinese lower case number string to ASCII number string.
    """
    CharToNumUpper_ko = cast("TransliterationModulesNewProto", 'CharToNumUpper_ko')
    """
    Transliterate a Korean Hanja upper case number string to ASCII number string.
    """
    CharToNumUpper_zh_CN = cast("TransliterationModulesNewProto", 'CharToNumUpper_zh_CN')
    """
    Transliterate a Simplified Chinese upper case number string to ASCII number string.
    """
    CharToNumUpper_zh_TW = cast("TransliterationModulesNewProto", 'CharToNumUpper_zh_TW')
    """
    Transliterate a Traditional Chinese upper case number string to ASCII number string.
    """
    END_OF_MODULE = cast("TransliterationModulesNewProto", 'END_OF_MODULE')
    """
    """
    FULLWIDTH_HALFWIDTH = cast("TransliterationModulesNewProto", 'FULLWIDTH_HALFWIDTH')
    """
    Transliterate a string from full width character to half width character.
    """
    HALFWIDTH_FULLWIDTH = cast("TransliterationModulesNewProto", 'HALFWIDTH_FULLWIDTH')
    """
    Transliterate a string from half width character to full width character.
    """
    HIRAGANA_KATAKANA = cast("TransliterationModulesNewProto", 'HIRAGANA_KATAKANA')
    """
    Transliterate a Japanese string from Hiragana to Katakana.
    """
    IGNORE_CASE = cast("TransliterationModulesNewProto", 'IGNORE_CASE')
    """
    Ignore case when comparing strings by transliteration service.
    """
    IGNORE_KANA = cast("TransliterationModulesNewProto", 'IGNORE_KANA')
    """
    Ignore Hiragana and Katakana when comparing strings by transliteration service.
    """
    IGNORE_WIDTH = cast("TransliterationModulesNewProto", 'IGNORE_WIDTH')
    """
    Ignore full width and half width character when comparing strings by transliteration service.
    
    Ignore full width and half width characters when comparing strings by transliteration service.
    """
    IgnoreBaFa_ja_JP = cast("TransliterationModulesNewProto", 'IgnoreBaFa_ja_JP')
    """
    Ignore Katakana and Hiragana Ba/Gua and Ha/Fa in Japanese fuzzy search.
    """
    IgnoreHyuByu_ja_JP = cast("TransliterationModulesNewProto", 'IgnoreHyuByu_ja_JP')
    """
    Ignore Katakana and Hiragana Hyu/Fyu and Byu/Gyu in Japanese fuzzy search.
    """
    IgnoreIandEfollowedByYa_ja_JP = cast("TransliterationModulesNewProto", 'IgnoreIandEfollowedByYa_ja_JP')
    """
    Ignore Katakana YA/A which follows the character in either I or E row in Japanese fuzzy search.
    
    Ignore Katakana YA/A following the character in either I or E row in Japanese fuzzy search.
    """
    IgnoreIterationMark_ja_JP = cast("TransliterationModulesNewProto", 'IgnoreIterationMark_ja_JP')
    """
    Ignore Hiragana and Katakana iteration mark in Japanese fuzzy search.
    """
    IgnoreKiKuFollowedBySa_ja_JP = cast("TransliterationModulesNewProto", 'IgnoreKiKuFollowedBySa_ja_JP')
    """
    Ignore Katakana KI/KU which follows the character in SA column in Japanese fuzzy search.
    
    Ignore Katakana KI/KU following the character in SA column in Japanese fuzzy search.
    """
    IgnoreMiddleDot_ja_JP = cast("TransliterationModulesNewProto", 'IgnoreMiddleDot_ja_JP')
    """
    Ignore middle dot in Japanese fuzzy search.
    """
    IgnoreMinusSign_ja_JP = cast("TransliterationModulesNewProto", 'IgnoreMinusSign_ja_JP')
    """
    Ignore dash or minus sign in Japanese fuzzy search.
    """
    IgnoreProlongedSoundMark_ja_JP = cast("TransliterationModulesNewProto", 'IgnoreProlongedSoundMark_ja_JP')
    """
    Ignore Japanese prolonged sound mark in Japanese fuzzy search.
    """
    IgnoreSeZe_ja_JP = cast("TransliterationModulesNewProto", 'IgnoreSeZe_ja_JP')
    """
    Ignore Katakana and Hiragana Se/Sye and Ze/Je in Japanese fuzzy search.
    """
    IgnoreSeparator_ja_JP = cast("TransliterationModulesNewProto", 'IgnoreSeparator_ja_JP')
    """
    Ignore separator punctuations in Japanese fuzzy search.
    """
    IgnoreSize_ja_JP = cast("TransliterationModulesNewProto", 'IgnoreSize_ja_JP')
    """
    Ignore Japanese normal and small sized character in Japanese fuzzy search.
    """
    IgnoreSpace_ja_JP = cast("TransliterationModulesNewProto", 'IgnoreSpace_ja_JP')
    """
    Ignore white space characters, include space, TAB, return, etc. in Japanese fuzzy search.
    """
    IgnoreTiJi_ja_JP = cast("TransliterationModulesNewProto", 'IgnoreTiJi_ja_JP')
    """
    Ignore Katakana and Hiragana Tsui/Tea/Ti and Dyi/Ji in Japanese fuzzy search.
    """
    IgnoreTraditionalKana_ja_JP = cast("TransliterationModulesNewProto", 'IgnoreTraditionalKana_ja_JP')
    """
    Ignore Japanese traditional Katakana and Hiragana character in Japanese fuzzy search.
    
    Ignore Japanese traditional Katakana and Hiragana characters in Japanese fuzzy search.
    """
    IgnoreTraditionalKanji_ja_JP = cast("TransliterationModulesNewProto", 'IgnoreTraditionalKanji_ja_JP')
    """
    Ignore Japanese traditional Kanji character in Japanese fuzzy search.
    
    Ignore Japanese traditional Kanji characters in Japanese fuzzy search.
    """
    IgnoreZiZu_ja_JP = cast("TransliterationModulesNewProto", 'IgnoreZiZu_ja_JP')
    """
    Ignore Katakana and Hiragana Zi/Zi and Zu/Zu in Japanese fuzzy search.
    """
    KATAKANA_HIRAGANA = cast("TransliterationModulesNewProto", 'KATAKANA_HIRAGANA')
    """
    Transliterate a Japanese string from Katakana to Hiragana.
    """
    LOWERCASE_UPPERCASE = cast("TransliterationModulesNewProto", 'LOWERCASE_UPPERCASE')
    """
    Transliterate a string from lower case to upper case.
    """
    LargeToSmall_ja_JP = cast("TransliterationModulesNewProto", 'LargeToSmall_ja_JP')
    """
    transliterate Japanese normal sized character to small sized character
    """
    NumToCharFullwidth = cast("TransliterationModulesNewProto", 'NumToCharFullwidth')
    """
    Transliterate a half width number string to full width number string.
    """
    NumToCharHangul_ko = cast("TransliterationModulesNewProto", 'NumToCharHangul_ko')
    """
    Transliterate an ASCII number string to Korean Hangul number string.
    """
    NumToCharKanjiShort_ja_JP = cast("TransliterationModulesNewProto", 'NumToCharKanjiShort_ja_JP')
    """
    Transliterate an ASCII number string to Japanese Kanji number string.
    """
    NumToCharLower_ko = cast("TransliterationModulesNewProto", 'NumToCharLower_ko')
    """
    Transliterate an ASCII number string to Korean Hanja lower case number string.
    """
    NumToCharLower_zh_CN = cast("TransliterationModulesNewProto", 'NumToCharLower_zh_CN')
    """
    Transliterate an ASCII number string to Simplified Chinese lower case number string.
    """
    NumToCharLower_zh_TW = cast("TransliterationModulesNewProto", 'NumToCharLower_zh_TW')
    """
    Transliterate an ASCII number string to Traditional Chinese lower case number string.
    """
    NumToCharUpper_ko = cast("TransliterationModulesNewProto", 'NumToCharUpper_ko')
    """
    Transliterate an ASCII number string to Korean Hanja upper case number string.
    """
    NumToCharUpper_zh_CN = cast("TransliterationModulesNewProto", 'NumToCharUpper_zh_CN')
    """
    Transliterate an ASCII number string to Simplified Chinese upper case number string.
    """
    NumToCharUpper_zh_TW = cast("TransliterationModulesNewProto", 'NumToCharUpper_zh_TW')
    """
    Transliterate an ASCII number string to Traditional Chinese upper case number string.
    """
    NumToTextFormalHangul_ko = cast("TransliterationModulesNewProto", 'NumToTextFormalHangul_ko')
    """
    Transliterate an ASCII number string to formal Korean Hangul number string in spellout format.
    """
    NumToTextFormalLower_ko = cast("TransliterationModulesNewProto", 'NumToTextFormalLower_ko')
    """
    Transliterate an ASCII number string to formal Korean Hanja lower case number string in spellout format.
    """
    NumToTextFormalUpper_ko = cast("TransliterationModulesNewProto", 'NumToTextFormalUpper_ko')
    """
    Transliterate an ASCII number string to formal Korean Hanja upper case number string in spellout format.
    """
    NumToTextInformalHangul_ko = cast("TransliterationModulesNewProto", 'NumToTextInformalHangul_ko')
    """
    Transliterate an ASCII number string to informal Korean Hangul number string in spellout format.
    """
    NumToTextInformalLower_ko = cast("TransliterationModulesNewProto", 'NumToTextInformalLower_ko')
    """
    Transliterate an ASCII number string to informal Korean Hanja lower case number string in spellout format.
    """
    NumToTextInformalUpper_ko = cast("TransliterationModulesNewProto", 'NumToTextInformalUpper_ko')
    """
    Transliterate an ASCII number string to informal Korean Hanja upper case number string in spellout format.
    """
    NumToTextLower_zh_CN = cast("TransliterationModulesNewProto", 'NumToTextLower_zh_CN')
    """
    Transliterate an ASCII number string to Simplified Chinese lower case number string in spellout format.
    """
    NumToTextLower_zh_TW = cast("TransliterationModulesNewProto", 'NumToTextLower_zh_TW')
    """
    Transliterate an ASCII number string to Traditional Chinese lower case number string in spellout format.
    """
    NumToTextUpper_zh_CN = cast("TransliterationModulesNewProto", 'NumToTextUpper_zh_CN')
    """
    Transliterate an ASCII number string to Simplified Chinese upper case number string in spellout format.
    """
    NumToTextUpper_zh_TW = cast("TransliterationModulesNewProto", 'NumToTextUpper_zh_TW')
    """
    Transliterate an ASCII number string to Traditional Chinese upper case number string in spellout format.
    """
    SmallToLarge_ja_JP = cast("TransliterationModulesNewProto", 'SmallToLarge_ja_JP')
    """
    transliterate Japanese small sized character to normal sized character
    """
    TextToNumFormalHangul_ko = cast("TransliterationModulesNewProto", 'TextToNumFormalHangul_ko')
    """
    Transliterate a Korean formal Hangul number string (spellout) to ASCII number string.
    """
    TextToNumFormalLower_ko = cast("TransliterationModulesNewProto", 'TextToNumFormalLower_ko')
    """
    Transliterate a Korean formal Hanja lower case number string (spellout) to ASCII number string.
    """
    TextToNumFormalUpper_ko = cast("TransliterationModulesNewProto", 'TextToNumFormalUpper_ko')
    """
    Transliterate a Korean formal Hanja upper case number string (spellout) to ASCII number string.
    """
    TextToNumInformalHangul_ko = cast("TransliterationModulesNewProto", 'TextToNumInformalHangul_ko')
    """
    Transliterate a Korean informal Hangul number string (spellout) to ASCII number string.
    """
    TextToNumInformalLower_ko = cast("TransliterationModulesNewProto", 'TextToNumInformalLower_ko')
    """
    Transliterate a Korean informal Hanja lower case number string (spellout) to ASCII number string.
    """
    TextToNumInformalUpper_ko = cast("TransliterationModulesNewProto", 'TextToNumInformalUpper_ko')
    """
    Transliterate a Korean informal Hanja upper case number string (spellout) to ASCII number string.
    """
    TextToNumLower_zh_CN = cast("TransliterationModulesNewProto", 'TextToNumLower_zh_CN')
    """
    Transliterate a Simplified Chinese lower case number string (spellout) to ASCII number string.
    """
    TextToNumLower_zh_TW = cast("TransliterationModulesNewProto", 'TextToNumLower_zh_TW')
    """
    Transliterate a Traditional Chinese lower case number string (spellout) to ASCII number string.
    """
    TextToNumUpper_zh_CN = cast("TransliterationModulesNewProto", 'TextToNumUpper_zh_CN')
    """
    Transliterate a Simplified Chinese upper case number string (spellout) to ASCII number string.
    """
    TextToNumUpper_zh_TW = cast("TransliterationModulesNewProto", 'TextToNumUpper_zh_TW')
    """
    Transliterate a Traditional Chinese upper case number string (spellout) to ASCII number string.
    """
    UPPERCASE_LOWERCASE = cast("TransliterationModulesNewProto", 'UPPERCASE_LOWERCASE')
    """
    Transliterate a string from upper case to lower case.
    """

__all__ = ['TransliterationModulesNew']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_item_listener import XItemListener as XItemListener_af710b81

class XCheckBox(XInterface_8f010a43):
    """
    gives access to the state of a check box and makes it possible to register for events.

    See Also:
        `API XCheckBox <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XCheckBox.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XCheckBox'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XCheckBox'

    @abstractmethod
    def addItemListener(self, l: XItemListener_af710b81) -> None:
        """
        registers a listener for item events.
        """
        ...
    @abstractmethod
    def enableTriState(self, b: bool) -> None:
        """
        enables or disables the tri state mode.
        """
        ...
    @abstractmethod
    def getState(self) -> int:
        """
        returns the state of the check box.
        """
        ...
    @abstractmethod
    def removeItemListener(self, l: XItemListener_af710b81) -> None:
        """
        unregisters a listener for item events.
        """
        ...
    @abstractmethod
    def setLabel(self, Label: str) -> None:
        """
        sets the label of the check box.
        """
        ...
    @abstractmethod
    def setState(self, n: int) -> None:
        """
        sets the state of the check box.
        """
        ...

__all__ = ['XCheckBox']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
from .x_number_format_previewer import XNumberFormatPreviewer as XNumberFormatPreviewer_3a570fa9
from .x_number_formatter import XNumberFormatter as XNumberFormatter_e3170d3b

class XNumberFormatter2(XNumberFormatPreviewer_3a570fa9, XNumberFormatter_e3170d3b):
    """
    Provides a unified interface for the NumberFormatter service to implement.
    
    **since**
    
        LibreOffice 4.0

    See Also:
        `API XNumberFormatter2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XNumberFormatter2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XNumberFormatter2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XNumberFormatter2'


__all__ = ['XNumberFormatter2']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class Selection(object):
    """
    Struct Class

    specifies a numerical range.

    See Also:
        `API Selection <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1Selection.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.Selection'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.awt.Selection'
    """Literal Constant ``com.sun.star.awt.Selection``"""

    def __init__(self, Min: typing.Optional[int] = 0, Max: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Min (int, optional): Min value.
            Max (int, optional): Max value.
        """
        super().__init__()

        if isinstance(Min, Selection):
            oth: Selection = Min
            self.Min = oth.Min
            self.Max = oth.Max
            return

        kargs = {
            "Min": Min,
            "Max": Max,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._min = kwargs["Min"]
        self._max = kwargs["Max"]


    @property
    def Min(self) -> int:
        """
        specifies the lower limit of the range.
        """
        return self._min

    @Min.setter
    def Min(self, value: int) -> None:
        self._min = value

    @property
    def Max(self) -> int:
        """
        specifies the upper limit of the range.
        """
        return self._max

    @Max.setter
    def Max(self, value: int) -> None:
        self._max = value


__all__ = ['Selection']
